type Coordinate = {
  type: 'Point'
  coordinates: [number, number] // [latitude, longitude]
}

type Address = {
  name: string
  street: string
  streetNo: string
  supplement: string | null
  zipCode: string
  city: string
  state: string
  country: null | string
}

type Location = {
  address: Address
  online: boolean
  privateLocation: boolean | null
  url: string
  coordinate: Coordinate
}

type Contact = {
  lastName: string
  firstName: string
  position: string
  email: string
  phone: string
  image: null | string
}

type SocialMediaContact = {
  type: 'INSTAGRAM' | 'FACEBOOK' | 'TWITTER' | 'LINKEDIN' | 'YOUTUBE' | string
  contact: string
}

type Period = {
  permanent: boolean
  start: string | null
  end: string | null
}

type Organisation = {
  id: number
  name: string
  logo: string | null
  image: string | null
}

type ThematicFocus =
  | 'SUSTAINABLE_BUILDING'
  | 'INTERNATIONAL_RESPONSIBILITY'
  | 'GENDER_EQUITY'
  | 'URBAN_DEVELOPMENT'
  | 'SUSTAINABLE_BUSINESS'
  | 'SUSTAINABLE_FINANCE'
  | 'CULTURAL_SOCIAL_CHANGE'
  | 'AGRICULTURE'
  | 'BIODIVERSITY'
  | 'SUSTAINABLE_LIFESTYLE'
  | 'MOBILITY'
  | 'HUMAN_RIGHTS'
  | 'TOURISM'
  | 'SOCIAL_JUSTICE'
  | 'PARTICIPATION'
  | 'PEACE'
  | 'SUSTAINABLE_GOVERNANCE'
  | 'CIRCULAR_ECONOMY'
  | 'CLIMATE_PROTECTION'
  | string

type ActivityType = 'EVENT' | string

type ImpactArea = 'LOCAL' | 'REGIONAL' | 'NATIONAL' | 'INTERNATIONAL' | string

export type Activity = {
  id: number
  createdBy?: string | null
  lastModifiedBy?: string | null
  createdAt?: string | null
  modifiedAt?: string | null
  name: string
  description: string
  sustainableDevelopmentGoals: number[]
  impactArea: ImpactArea
  contact: Contact
  location: Location
  thematicFocus: ThematicFocus[]
  activityType: ActivityType
  externalId: string | null
  registerUrl: string | null
  approvedUntil: string | null
  period: Period
  logo: string | null
  image: string | null
  socialMediaContacts?: SocialMediaContact[]
  bannerImageMode: string | null
  organisation: Organisation
}

type Sort = {
  direction: 'ASC' | 'DESC'
  property: string
  ignoreCase: boolean
  nullHandling: 'NATIVE' | string
  descending: boolean
  ascending: boolean
}

type Pageable = {
  pageNumber: number
  pageSize: number
  sort: Sort[]
  offset: number
  paged: boolean
  unpaged: boolean
}

type ResultType = 'ACTIVITY' | string

export type ActivityResult = {
  name: string
  description: string
  resultType: ResultType
  activity: Activity
  location: Location
}

export type ActivitiesPageResponse = {
  content: ActivityResult[]
  pageable: Pageable
  totalPages: number
  totalElements: number
  last: boolean
  numberOfElements: number
  size: number
  number: number
  sort: Sort[]
  first: boolean
  empty: boolean
}
